@@ -10,7 +10,7 @@
 #include "theme.h"
 #include "../file_helper.h"
 
-static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, gchar* theme_name, int variation);
+static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, const gchar* theme_name, int variation);
 
 gboolean composition_game_file_helper_load_from_file(jammo_theme* theme, gpointer data,JammoEditingTrackView* bottom_track_view ,JammoEditingTrackView* upper_track_view) {
 
@@ -46,7 +46,7 @@ object = json_node_get_object (root);
 g_assert (object != NULL);
 
 
-gchar* theme_name ="";
+const gchar* theme_name;
 gint variation =-1;
 gint format_version = 1; //jammo-0.7.7 and all before that is format_version=1
 	//string
@@ -61,9 +61,10 @@ gint format_version = 1; //jammo-0.7.7 and all before that is format_version=1
 	//string
 	node = json_object_get_member (object, "theme");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
-		theme_name =(gchar*)  json_node_get_string (node);
+		theme_name = json_node_get_string (node);
 		//printf("theme: '%s'\n",theme_name);
 	}
+	else theme_name="";
 
 	//int
 	node = json_object_get_member (object, "variation");
@@ -143,7 +144,7 @@ return TRUE;
 /*
  * This is used loading format-version=1 compositions.
  */
-static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, gchar* theme_name, int variation) {
+static void load_this_sample_array_to_this_track_view_legacy1(JsonNode *sub_node,JammoEditingTrackView* track_view,jammo_theme* theme, const gchar* theme_name, int variation) {
 	//Array  //sub_node = json_object_get_member (sub_object, "samples");
 	if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_ARRAY){
 		JsonArray* sample_array =  json_node_get_array (sub_node);
