@@ -7,9 +7,7 @@ This file is for clutter based gui.
 #ifndef GAMESMENU_H_
 #define GAMESMENU_H_
 
-gboolean start_gamesmenu();
-void init_gamesmenu();
-gboolean gamesmenu_is_initialized();
+void gamesmenu_show();
 void gamesmenu_start_first_task_on_this_level(const char* levelname);
-
+void gamesmenu_start_instructions_for_level1();
 #endif /* GAMESMENU_H_ */
