@@ -22,8 +22,8 @@ static int selectedQuestion = 0;
 static GList *helpdesk_messages = 0;
 static GList *paramsList = 0;
 
-TextField addquestion_titleTextField;
-TextField addquestion_questionTextField;
+static TextField addquestion_titleTextField;
+static TextField addquestion_questionTextField;
 
 void start_helpdesk(void)
 {
