@@ -193,7 +193,8 @@ static int metro(int pointA[BUFFER_SIZE] ){
     for (i=0;i<BUFFER_SIZE;i++){
         temp =+ pow(pointA[i],2);
     }
-    return (int)sqrt(temp);
+    int r = sqrt(temp);
+    return r;
 }
 
 static int motion_detect(int e, int firsttime){
