@@ -23,10 +23,10 @@ static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data);
 static list_type list = {0, 0};
 static gboolean isrecording_voice_comment = FALSE;
 static gboolean voice_comment_ready = FALSE;
-gchar* recording_filename;
-JammoSequencer* sequencer;
-GList *paramsList = 0;
-GList *labelParamsList = 0;
+static gchar* recording_filename;
+static JammoSequencer* static_sequencer;
+GList *paramsList = 0; //This is used from other files too
+static GList *labelParamsList = 0;
 
 
 void start_jammosongs(){
@@ -302,21 +302,21 @@ void record_voice_comment(){
 	
 	jammo_meam_init(NULL, NULL, "jammo_test_duration_cache"); 	
 	
-	sequencer = jammo_sequencer_new();
-	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_recording_stopped), NULL);
+	static_sequencer = jammo_sequencer_new();
+	g_signal_connect(static_sequencer, "stopped", G_CALLBACK(on_recording_stopped), NULL);
 
 	backing_track = jammo_backing_track_new(backing_track_filename);
-	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track)); //max length 30s
+	jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(backing_track)); //max length 30s
 	
 	recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
-	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track)); 
+	jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(recording_track));
 
 	g_print("Recording...\n");
 	g_print("Max length is 30 seconds.\n");
 
 	isrecording_voice_comment = TRUE;
 
-	jammo_sequencer_play(JAMMO_SEQUENCER(sequencer));
+	jammo_sequencer_play(JAMMO_SEQUENCER(static_sequencer));
 	
 	g_free(backing_track_filename);
 }
@@ -325,7 +325,7 @@ void stop_recording()
 {
 	isrecording_voice_comment = FALSE;
 	voice_comment_ready = TRUE;
-	jammo_sequencer_stop(JAMMO_SEQUENCER(sequencer));
+	jammo_sequencer_stop(JAMMO_SEQUENCER(static_sequencer));
 }
 
 static void on_recording_stopped(JammoSequencer* sequencer, gpointer user_data) 
