@@ -3,6 +3,7 @@
 #include "jammosongs.h"
 #include <string.h>
 #include "avatar_editor.h"
+#include "../../cem/cem.h"
 
 profile_view_params *params;
 static Avatar avatar = {0,0,0,0};
@@ -16,7 +17,7 @@ void start_profile_view(profile_view_params *pvp){
 	guint32 avatar_id = 0;	
 	gems_peer_profile *profile = gems_profile_manager_get_profile_of_user(params->user_id);
 
-	printf("Starting profileviewer\n");
+	cem_add_to_log("Starting profileviewer", J_LOG_DEBUG);
 	
 	if(strcmp(params->parent_view, "jammosongs") == 0)
 		tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("jammosongs-view")));
@@ -56,7 +57,7 @@ void start_profile_view(profile_view_params *pvp){
 		
 		g_free(age);
 	}else
-		puts("can't find 'profile-view' ");
+		cem_add_to_log("can't find 'profile-view' ", J_LOG_ERROR);
 	
 
 }
