@@ -98,7 +98,7 @@ object = json_node_get_object (root);
 g_assert (object != NULL);
 
 	gint tempo = 110; //'normal' tempo
-	gchar* pitch ="D";  //'normal' pitch
+	const gchar* pitch;
 
 	guint64 duration  = 0; //Duration is mandatory
 
@@ -108,19 +108,21 @@ if (load_only_backingtrack){
 	node = json_object_get_member (object, "tempo");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		tempo = json_node_get_int (node);
-		printf("tempo: '%d'\n",tempo);
+		//printf("tempo: '%d'\n",tempo);
 	}
 	//string
 	node = json_object_get_member (object, "pitch");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
-		pitch = (gchar*)  json_node_get_string (node);
-		printf("pitch: '%s'\n",pitch);
+		pitch = json_node_get_string (node);
 	}
+	pitch ="D";  //'normal' pitch
+	//printf("pitch: '%s'\n",pitch);
+
 	//guint64
 	node = json_object_get_member (object, "duration");
 	if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
 		duration =  json_node_get_int (node);
-		printf("duration: '%" G_GUINT64_FORMAT "'\n",duration);
+		//printf("duration: '%" G_GUINT64_FORMAT "'\n",duration);
 	}
 
 	jammo_sequencer_set_tempo(static_sequencer,tempo);
@@ -156,16 +158,17 @@ if (load_only_backingtrack){
 
 		if (track_node!=NULL && JSON_NODE_TYPE(track_node) == JSON_NODE_OBJECT){
 			//printf("Found track!\n");
-			gchar* track_type="";
-			gchar* name_of_track="";
+			const gchar* track_type;
+			const gchar* name_of_track;
 
 			JsonObject* sub_object = json_node_get_object(track_node);
 			JsonNode *sub_node;
 			sub_node = json_object_get_member (sub_object, "track-type");
 			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-				track_type =(gchar*)  json_node_get_string (sub_node);
-				//printf(" track-type: '%s'\n",track_type);
+				track_type = json_node_get_string (sub_node);
 				}
+			else track_type="";
+			//printf(" track-type: '%s'\n",track_type);
 
 			//boolean. We need this to construct track_view
 			gboolean muted=FALSE; //default
@@ -185,45 +188,49 @@ if (load_only_backingtrack){
 			//string
 			sub_node = json_object_get_member (sub_object, "name");
 			if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-				name_of_track =(gchar*)  json_node_get_string (sub_node);
-				//printf(" name of track: '%s'\n",name_of_track);
+				name_of_track = json_node_get_string (sub_node);
 			}
+			else name_of_track="";
+			//printf(" name of track: '%s'\n",name_of_track);
 
 
 			//BACKING-TRACK
 			if (strncmp(track_type, "BackingTrack", 12) == 0) {
 				//printf("Found BackingTrack\n");
-				gchar* backing_track_filename="";
+				const gchar* backing_track_filename;
 				//string
 				sub_node = json_object_get_member (sub_object, "audio-file");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					backing_track_filename =(gchar*)  json_node_get_string (sub_node);
+					backing_track_filename = json_node_get_string (sub_node);
 					//printf("backing_track_filename: '%s'\n",backing_track_filename);
 
-				gchar* image_filename="";
+				const gchar* image_filename;
 				//string
 				sub_node = json_object_get_member (sub_object, "image-file");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					image_filename =(gchar*)  json_node_get_string (sub_node);
-					//printf("image_filename: '%s'\n",image_filename);
+					image_filename = json_node_get_string (sub_node);
 				}
+				else image_filename="";
+				//printf("image_filename: '%s'\n",image_filename);
 
 				track_view=sequencer_track_view_create_backing_track(muted,volume,backing_track_filename,image_filename,name_of_track);
 				}
+				else backing_track_filename="";
 			} //Backing-track over
 
 
 			//EDITING-TRACK
 			if(strncmp(track_type, "EditingTrack", 12) == 0) {
 				gint e_track_type=JAMMO_SAMPLE_UNTYPED;
-				gchar* editing_track_type="";
+				const gchar* editing_track_type;
 
 				//string
 				sub_node = json_object_get_member (sub_object, "editing-track-type");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					editing_track_type =(gchar*)  json_node_get_string (sub_node);
-					//printf("editing-track-type: '%s'\n",editing_track_type);
+					editing_track_type = json_node_get_string (sub_node);
 				}
+				else editing_track_type="";
+				//printf("editing-track-type: '%s'\n",editing_track_type);
 
 				GEnumClass* enum_class = G_ENUM_CLASS(g_type_class_ref(JAMMO_TYPE_SAMPLE_TYPE));
 				GEnumValue* enum_value = g_enum_get_value_by_nick(enum_class, editing_track_type);
@@ -253,7 +260,7 @@ if (load_only_backingtrack){
 				//string
 				sub_node = json_object_get_member (sub_object, "note-file");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					gchar* note_file = (gchar*) json_node_get_string (sub_node);
+					const gchar* note_file = json_node_get_string (sub_node);
 					//printf("loading notes from file '%s'\n",note_file);
 					GList* events = jammomidi_file_to_glist(note_file);
 					jammo_miditrack_view_add_event_list(JAMMO_MIDITRACK_VIEW(track_view),events);
@@ -278,7 +285,7 @@ if (load_only_backingtrack){
 				//string
 				sub_node = json_object_get_member (sub_object, "note-file");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					gchar* note_file = (gchar*) json_node_get_string (sub_node);
+					const gchar* note_file =  json_node_get_string (sub_node);
 					printf("loading notes from file '%s'\n",note_file);
 					GList* events = jammo_slider_event_file_to_glist(note_file);
 					jammo_slider_track_set_event_list(JAMMO_SLIDER_TRACK(track), events); //We need access to track here!
@@ -337,10 +344,11 @@ void secuencer_sync_buttons_to_pitch_and_tempo() {
 	int starting_tempo = jammo_sequencer_get_tempo(static_sequencer);
 	//printf("starting_tempo %d\n",starting_tempo);
 	ClutterActor* button;
-	gchar* name_button="";
+	const gchar* name_button;
 	if(starting_tempo== 130)       name_button="tempo-button-fast";
 	else if(starting_tempo== 110)  name_button="tempo-button-normal";
 	else if(starting_tempo==90)    name_button="tempo-button-slow";
+	else name_button="";
 
 	button =jammo_get_actor_by_id(name_button);
 	if (button)
@@ -529,13 +537,14 @@ gboolean fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointe
 	if (name==NULL)
 		return TRUE;
 
-	gchar* new_pitch = "G";
+	const gchar* new_pitch;
 	if (strncmp(name,"high",4)==0)
 			new_pitch = "G";
 	else if (strncmp(name,"normal",6)==0)
 			new_pitch = "D";
 	else if (strncmp(name,"low",3)==0)
 			new_pitch = "A";
+	else new_pitch = "G";
 
 	gchar* message = g_strdup_printf("pitch '%s'='%s' clicked",name,new_pitch);
 	cem_add_to_log(message,J_LOG_USER_ACTION);
