@@ -370,7 +370,7 @@ Functions for json
 **************************/
 
 gboolean fullsequencer_play_clicked (TangleButton* tanglebutton, gpointer none){
-	gchar* message;
+	const gchar* message;
 	if (tangle_button_get_selected(tanglebutton))
 		message = "fullsequencer: Play-Button pressed";
 	else
@@ -447,7 +447,7 @@ void sequencer_track_view_set_duration(guint64 duration) {
 static int track_height=50;
 
 //Creates control-panel for given track_view.
-static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterActor* label, gchar* name_of_track_view, gboolean muted, gfloat volume) {
+static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterActor* label, const gchar* name_of_track_view, gboolean muted, gfloat volume) {
 
 	ClutterActor* panel_widget = tangle_widget_new();
 	tangle_widget_set_layout(TANGLE_WIDGET(panel_widget), tangle_box_layout_new());
@@ -520,7 +520,7 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 
 
 
-ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gchar* name_of_track_view) {
+ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
 	//printf("Making editing track (duration: %" G_GUINT64_FORMAT ")\n", duration_of_tracks);
@@ -533,7 +533,7 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 		duration_of_one_slot = duration_of_tracks / number_of_slots;
 		
 	ClutterActor *label;
-	gchar* name_of_label_button="";
+	const gchar* name_of_label_button;
 	JammoTrack* track;
 
 	//MEAM-track
@@ -602,7 +602,7 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 }
 
 
-ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, gchar* audio, gchar* image, gchar* name_of_track_view) {
+ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, const gchar* audio, const gchar* image, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
 
@@ -615,7 +615,7 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 
 
 	ClutterActor *label;
-	gchar* name_of_label_button="";
+	const gchar* name_of_label_button;
 	JammoTrack* track;
 	ClutterActor* track_view_actor;
 
@@ -651,14 +651,14 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 }
 
 
-ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar* name_of_track_view) {
+ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, const gchar* name_of_track_view) {
 	JammoSequencer* sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	guint64 duration_of_tracks = jammo_sequencer_get_duration(sequencer);
 	//printf("Making editing track (duration: %" G_GUINT64_FORMAT ")\n", duration_of_tracks);
 
 	guint64 duration_of_one_slot = duration_of_tracks / number_of_slots;
 	ClutterActor *label;
-	gchar* name_of_label_button="";
+	const gchar* name_of_label_button;
 	JammoTrack* track;
 	ClutterActor* track_view_actor;
 
