@@ -37,10 +37,10 @@ enum {
 
 void sequencer_track_view_set_duration(guint64 duration);
 
-ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, gchar* name_of_track_view);
-ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, gchar*
+ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat volume, gint e_type, const gchar* name_of_track_view);
+ClutterActor* sequencer_track_view_create_instrument_track(gboolean muted, gfloat volume, gint instrument_type, const gchar*
 name_of_track_view);
-ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, gchar* audio, gchar* image, gchar* name_of_track_view);
+ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat volume, const gchar* audio, const gchar* image, const gchar* name_of_track_view);
 
 bool save_sequencer_state();
 
