@@ -55,7 +55,7 @@ This file contain helper functions, which are meant to be used via chum.
 
 */
 
-void save_composition(gchar* folder, gchar* to_filename, ClutterActor* sequencer_widget, gchar* user_metadata) {
+void save_composition(const gchar* folder, const gchar* to_filename, ClutterActor* sequencer_widget, gchar* user_metadata) {
 
 	//Generate filename based on timestamp
 	char timestamp_now [80];
@@ -373,7 +373,7 @@ static int string_compare( gconstpointer a, gconstpointer b ){
 }
 
 
-static GList *scan_and_sort_directory( gchar *directory_name ) {
+static GList *scan_and_sort_directory( const gchar *directory_name ) {
    GError *error = NULL;
    guint flags = 0;
 
@@ -439,7 +439,7 @@ GList *file_helper_get_all_songs() {
   return song_list;
 }
 
-GList *file_helper_get_all_files(char* directory) {
+GList *file_helper_get_all_files(const char* directory) {
   GList *song_list = NULL;
   gint index = 0;
   gchar *song_name = NULL;
@@ -464,7 +464,7 @@ GList *file_helper_get_all_files(char* directory) {
   return song_list;
 }
 
-GList *file_helper_get_all_files_without_path(char* directory) {
+GList *file_helper_get_all_files_without_path(const char* directory) {
   GList *song_list = NULL;
   gint index = 0;
   gchar *song_name = NULL;
