@@ -127,7 +127,7 @@ static guint64 get_duration_of_slot(JammoEditingTrack * editing_track) {
 	guint64 one_second = 1000000000L;
 	guint64 big = temp * one_second * jammo_editing_track_get_time_signature_note_value(editing_track);
 	// 4.0 comes from bpm (x quarter notes in a minute)
-	duration_of_slot = ((gdouble)big / (gdouble)jammo_editing_track_get_tempo(editing_track) / 4.0);
+	duration_of_slot = ((gdouble)big / jammo_editing_track_get_tempo(editing_track) / 4.0);
 	return duration_of_slot;
 }
 
