@@ -6,13 +6,13 @@
 void configure_init_directories(gboolean small_game);
 void configure_release_directories();
 
-gchar* configure_get_jammo_directory();
-gchar* configure_get_singings_directory();
-gchar* configure_get_compositions_directory();
+const gchar* configure_get_jammo_directory();
+const gchar* configure_get_singings_directory();
+const gchar* configure_get_compositions_directory();
 
-gchar* configure_get_projects_directory();
-gchar* configure_get_finalized_directory();
-gchar* configure_get_log_directory();
+const gchar* configure_get_projects_directory();
+const gchar* configure_get_finalized_directory();
+const gchar* configure_get_log_directory();
 /**
  * Defines default folders.
  */
@@ -44,4 +44,6 @@ gchar* configure_get_log_directory();
 #define _(string)    gettext(string)
 
 
+#define BUFFERER_ENABLED
+
 #endif /* _CONFIGURE_H_ */
