@@ -40,7 +40,7 @@ GTimer* testtimer;
 gems_communication_data* gems_communication_init()
 {
 	// Communication data struct
-	gems_communication_data* data = (gems_communication_data*)g_malloc(sizeof(gems_communication_data));
+	gems_communication_data* data = g_new0(gems_communication_data,sizeof(gems_communication_data));
 	
 	// Communication list
 	data->connections = NULL;
@@ -437,7 +437,7 @@ gint gems_communication_advert_group()
 				{					
 					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE, element, msg) == FALSE)
 					{
-						gchar* logmsg = g_strdup_printf("gems_communication_advert_group: cannot send OFFER_GROUP to device %u with user %u",
+						logmsg = g_strdup_printf("gems_communication_advert_group: cannot send OFFER_GROUP to device %u with user %u",
 							ph_c_connection_get_device_checksum(element->connection), element->profile->id);
 						cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
@@ -716,15 +716,15 @@ gboolean gems_communication_write_encrypted_data(guint16 type, gems_connection*
 }
 
 // Write message to socket
-gint gems_communication_write_data(gint socket, gems_message* data)
+gint gems_communication_write_data(gint sock_fd, gems_message* data)
 {
-	return write(socket, (gchar*)data->message, data->length);
+	return write(sock_fd, (gchar*)data->message, data->length);
 }
 
 // Read data from socket, place data in gpointer* data
-gint gems_communication_read_data(gint socket, void* data, gint length)
+gint gems_communication_read_data(gint sock_fd, void* data, gint length)
 {
-	return read(socket, (gchar*)data, length);
+	return read(sock_fd, (gchar*)data, length);
 }
 
 gint gems_communication_process_connected()
@@ -1551,7 +1551,7 @@ gint gems_communication_probe_for_peerhood()
 		return TRUE; // Got NULL reference, try again
 	}
 	
-	gchar** args = (gchar**)g_malloc(sizeof(gchar**));
+	gchar** args = g_new0(gchar*,1);
 	args[0] = "./jammo";
 	if(ph_c_init(data->ph,1,args) == TRUE)
 	{
@@ -1629,7 +1629,7 @@ void gems_communication_peerhood_close_detected()
 
 gems_teacher_connection* gems_teacher_connection_init()
 {
-	gems_teacher_connection* tc = (gems_teacher_connection*)g_malloc(sizeof(gems_teacher_connection));
+	gems_teacher_connection* tc = g_new0(gems_teacher_connection,sizeof(gems_teacher_connection));
 	
 	tc->connection = NULL;
 	
