@@ -40,7 +40,7 @@ gems_components* gems_get_data()
 	if(!gems_data)
 	{
 		// Allocate memory and set internal struct pointers to NULL
-		gems_data = (gems_components*)g_malloc(sizeof(gems_components));
+		gems_data = g_new0(gems_components,sizeof(gems_components));
 		gems_data->pm = NULL;
 		gems_data->ph = NULL;
 		gems_data->ph_cb = NULL;
@@ -68,7 +68,7 @@ gems_components* gems_get_data()
 
 ProfileManager* gems_get_profile_manager()
 {
-	return gems_get_data()->pm;
+	return profilemanager_get_manager();
 }
 
 MPeerHood* gems_get_peerhood()
@@ -197,7 +197,7 @@ guint gems_get_teacher_profile_request_count()
 	return gems_get_data()->teacher_profile_requests;
 }
 
-void gems_set_login_username(gchar* username, gboolean forced)
+void gems_set_login_username(const gchar* username, gboolean forced)
 {
 	gems_get_data()->username_to_login = g_strdup(username);
 	gems_get_data()->username_forced = forced;
@@ -264,7 +264,7 @@ void jammo_gems_init(int argc, char* argv[])
 	for(gint i = 0; i < TO_FUNCTIONS; i++) components->timeout_functions[i] = 0;
 	
 	// Profile manager
-	components->pm = profilemanager_new_manager();
+	components->pm = profilemanager_get_manager();
 	
 	// Initialize communication
 	components->communication = gems_communication_init(components->communication);
