@@ -25,14 +25,12 @@
 gems_message* gems_create_error_message(guint16 errortype, guint16 serviceid)
 {	
 	// allocate struct
-	gems_message* errormsg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* errormsg = g_new(gems_message,sizeof(gems_message));
 	
 	// error message = error + length + service id + error type + message
 	errormsg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + strlen(get_errormessage(errortype)) + 1;
 	
-	errormsg->message = (gchar*)g_malloc(sizeof(gchar*) * errormsg->length);
-	
-	memset(errormsg->message,'\0',errormsg->length);
+	errormsg->message = g_new0(gchar,sizeof(gchar) * errormsg->length);
 	
 	guint16 error = ERROR_MSG;
 	guint position = 0;
@@ -65,7 +63,7 @@ void gems_clear_message(gems_message* message)
 	}
 }
 
-gchar* get_errormessage(guint16 errortype)
+const gchar* get_errormessage(guint16 errortype)
 {
 	switch(errortype)
 	{
@@ -125,7 +123,7 @@ gchar* get_errormessage(guint16 errortype)
 
 gems_message* gems_create_message_service_jammo(guint16 type)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
@@ -133,9 +131,7 @@ gems_message* gems_create_message_service_jammo(guint16 type)
 	// Adding version info
 	if(type == VERSION_REPLY) msg->length = msg->length + strlen(VERSION) + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(JAMMO_SERVICE_ID);
@@ -157,7 +153,7 @@ gems_message* gems_create_message_service_jammo(guint16 type)
 
 gems_message* gems_create_message_service_profile(guint16 type)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	const gchar* fname = NULL;
 	const gchar* lname = NULL;
@@ -198,9 +194,7 @@ gems_message* gems_create_message_service_profile(guint16 type)
 		msg->length = msg->length + strlen(fname) + 1 + strlen(lname) + 1 + sizeof(guint32);
 	}
 		
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(PROFILE_SERVICE_ID);
@@ -261,14 +255,12 @@ gems_message* gems_create_message_service_profile(guint16 type)
 
 gems_message* gems_create_message_profile_request(guint16 type)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16);
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(PROFILE_SERVICE_ID);
@@ -290,14 +282,12 @@ gems_message* gems_create_message_profile_request(guint16 type)
 
 gems_message* gems_create_message_teacher_service_profile_request(gchar* username)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + strlen(username) + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
@@ -320,13 +310,13 @@ gems_message* gems_create_message_teacher_service_profile_request(gchar* usernam
 
 gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, guint length, gchar* username)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	guint16 unamelen = strlen(username) + 1; // 1 NULL to separate username and encrypted profile
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + unamelen + length ;
 	
-	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
@@ -357,12 +347,12 @@ gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, gui
 
 gems_message* gems_create_message_password_changed(guchar* newpasshash, guchar* encnewpass, guint encpasslen, guint8 pwlen)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint32) + SHA_HASH_LENGTH + encpasslen + sizeof(guint8) ;
 	
-	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
@@ -406,7 +396,7 @@ gems_message* gems_create_message_password_changed(guchar* newpasshash, guchar*
 */
 gems_message* gems_create_message_group_management_notify(guint16 type, guint32 groupid, guint32 member)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
@@ -416,7 +406,7 @@ gems_message* gems_create_message_group_management_notify(guint16 type, guint32
 		if(type == MEMBER_DROPPED || type == NEW_MEMBER) msg->length = msg->length + sizeof(guint32);
 	}
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(GROUP_SERVICE_ID);
@@ -453,7 +443,7 @@ gems_message* gems_create_message_group_management_notify(guint16 type, guint32
 gems_message* gems_create_message_group_management_group_info(guint16 type)
 {
 	gems_group_info* info = gems_get_data()->service_group->group_info;
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	// service id + packet length + command id + group id
@@ -477,7 +467,7 @@ gems_message* gems_create_message_group_management_group_info(guint16 type)
 			break;
 	}
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(GROUP_SERVICE_ID);
@@ -565,7 +555,7 @@ gems_message* gems_create_message_group_management_group_info(guint16 type)
 
 gems_message* gems_create_message_group_management_group_info_teacher(guint16 type, gems_group_info* groupinfo, guint16 track_id)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	// service id + packet length + command id + group id
@@ -578,7 +568,7 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 	print_group(groupinfo);
 
 
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(GROUP_SERVICE_ID);
@@ -637,14 +627,12 @@ gems_message* gems_create_message_group_management_group_info_teacher(guint16 ty
 
 gems_message* gems_create_message_collaboration_action_confirmed()
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
 
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -666,17 +654,14 @@ gems_message* gems_create_message_collaboration_action_confirmed()
 //Message for adding or removing a loop - Note - currently using paths of image and wav files!
 gems_message* gems_create_message_collaboration_action_vi_single(guint16 type, const gchar png_name[], const gchar wav_name[], guint16 slot)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16);
 
 	msg->length = msg->length + strlen(png_name) + 1 + strlen(wav_name) + 1 + sizeof(guint16);
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -712,17 +697,14 @@ gems_message* gems_create_message_collaboration_action_vi_single(guint16 type, c
 //Message for transferring the song file - used when starting a game (or synchronizing after disconnection?) 
 gems_message* gems_create_message_collaboration_action_song_info(guint16 type, const gchar song_info[])
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
 
 	msg->length = msg->length + strlen(song_info) + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -747,15 +729,12 @@ gems_message* gems_create_message_collaboration_action_song_info(guint16 type, c
 //Message for adding or removing a loop - Note - currently using paths of image and wav files!
 gems_message* gems_create_message_collaboration_action_loop(guint16 type, guint loop_id, guint slot)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint) + sizeof(guint) + sizeof(guint16) + sizeof(guint);
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -791,15 +770,12 @@ gems_message* gems_create_message_collaboration_action_loop(guint16 type, guint
 
 gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint) + g_list_length(list) * (2*sizeof(guint32));
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -835,15 +811,12 @@ gems_message* gems_create_message_collaboration_action_loop_sync(GList * list)
 
 gems_message* gems_create_message_collaboration_action_midi_series(guint16 type, guint16 instrument_id, GList * list)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint) + sizeof(guint16) + sizeof(guint16) + g_list_length(list) * (sizeof(unsigned char)+sizeof(GstClockTime)+sizeof(JammmoMidiEventType));
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -890,15 +863,12 @@ gems_message* gems_create_message_collaboration_action_midi_series(guint16 type,
 }
 gems_message* gems_create_message_collaboration_action_slider_series(guint16 type, guint16 instrument_id, GList * list)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint) + sizeof(guint16) + sizeof(guint16) + g_list_length(list) * (sizeof(guint32)+sizeof(GstClockTime)+sizeof(JammoSliderEventType));
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(COLLABORATION_SERVICE_ID);
@@ -946,13 +916,12 @@ gems_message* gems_create_message_collaboration_action_slider_series(guint16 typ
 
 gems_message* gems_create_message_control_mode(guint16 type, guint16 cntrl_type, guint16 lock_mode)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + sizeof(guint16) + sizeof(guint16);
 
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
@@ -979,13 +948,12 @@ gems_message* gems_create_message_control_mode(guint16 type, guint16 cntrl_type,
 
 gems_message* gems_create_message_control_ok(guint16 type)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));	
 	guint position = 0;
 
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
 
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
@@ -1004,14 +972,12 @@ gems_message* gems_create_message_control_ok(guint16 type)
 
 gems_message* gems_create_message_control_set_login_name(gchar* username)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + strlen(username) + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
@@ -1034,14 +1000,12 @@ gems_message* gems_create_message_control_set_login_name(gchar* username)
 
 gems_message* gems_create_message_control_force_login(gchar* password, guint8 passlen)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + passlen + 1 + 1;
 	
-	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
-	
-	memset(msg->message,'\0',msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
@@ -1067,12 +1031,12 @@ gems_message* gems_create_message_control_force_login(gchar* password, guint8 pa
 
 gems_message* gems_create_message_control_get_login()
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
 	
-	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(CONTROL_SERVICE_ID);
@@ -1091,12 +1055,12 @@ gems_message* gems_create_message_control_get_login()
 
 gems_message* gems_create_message_mentor_log_message(guint16 type, char *message)
 {
-	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	gems_message* msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16) + strlen(message) + 1;
 	
-	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(MENTOR_SERVICE_ID);
@@ -1111,7 +1075,7 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 	position = position + sizeof(guint16);
 	
 	// Log message
-	g_strlcat(&msg->message[position],message,msg->length);
+	g_strlcat(&msg->message[position],message,msg->length - position);
 	
 	return msg;
 
@@ -1120,13 +1084,13 @@ gems_message* gems_create_message_mentor_log_message(guint16 type, char *message
 
 gems_message* gems_create_general_message(gems_message* msg, guint16 serviceid, guint32 length, guint16 type)
 {
-	if(msg == NULL) msg = (gems_message*)g_malloc(sizeof(gems_message));
+	if(msg == NULL) msg = g_new(gems_message,sizeof(gems_message));
 	guint position = 0;
 	
 	if(length == 0) msg->length = sizeof(guint16) + sizeof(guint32) + sizeof(guint16);
 	else msg->length = length;
 	
-	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	msg->message = g_new0(gchar,sizeof(gchar) * msg->length);
 	
 	// Service id 16 bits
 	*(guint16*)&msg->message[position] = g_htons(serviceid);
