@@ -155,8 +155,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 						}
 					}
 					
-					msgdata = (gchar*)g_malloc(sizeof(gchar*) * dataleft);
-					memset(msgdata,'\0',dataleft);
+					msgdata = g_new0(gchar,sizeof(gchar) * dataleft);
 			
 					// Read the rest - should be chars
 					if((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection),msgdata,dataleft)) != dataleft)
@@ -193,8 +192,7 @@ GList* gems_service_jammo_process_list(GList* list, gboolean service)
 				{
 					// left = packet length - read amount
 					dataleft = gems_connection_get_32(element, sizeof(guint16)) - gems_connection_partial_data_amount(element);
-					msgdata = (gchar*)g_malloc(sizeof(gchar*) * dataleft);
-					memset(msgdata,'\0',dataleft);
+					msgdata = g_new(gchar,sizeof(gchar) * dataleft);
 					
 					if((bytesread = gems_communication_read_data(ph_c_connection_get_fd(element->connection),msgdata, dataleft)) < dataleft)
 					{
@@ -625,7 +623,7 @@ gboolean gems_service_jammo_process_error(gems_connection *element, gboolean ser
 gems_service_jammo* gems_service_jammo_init()
 {
 	// JamMo service
-	gems_service_jammo* data = (gems_service_jammo*)g_malloc(sizeof(gems_service_jammo));
+	gems_service_jammo* data = g_new(gems_service_jammo,sizeof(gems_service_jammo));
 	
 	// Initialize JamMo servicelist
 	data->connections = NULL;
