@@ -22,7 +22,7 @@ static void empty_callback_profile(jammo_profile_container* prof){}
 gems_service_profile* gems_service_profile_init()
 {
 	teacher_server_callback_new_profile=empty_callback_profile;
-	gems_service_profile* data = (gems_service_profile*)g_malloc(sizeof(gems_service_profile));
+	gems_service_profile* data = g_new(gems_service_profile,sizeof(gems_service_profile));
 	data->enabled = FALSE;
 	data->port = 0;
 	return data;
@@ -181,7 +181,7 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 			
 			guint32 points = gems_connection_get_32(element,position);
 			
-			gchar* logmsg = g_strdup_printf("Got full profile: userid:%u username: %s age:%d fullname:%s %s points:%u avatar:%u", 
+			logmsg = g_strdup_printf("Got full profile: userid:%u username: %s age:%d fullname:%s %s points:%u avatar:%u", 
 					userid,username,uage,firstname,lastname,points,avatarid);
 			cem_add_to_log(logmsg,J_LOG_INFO);
 			g_free(logmsg);
