@@ -109,7 +109,7 @@ gems_connection* gems_new_gems_connection(MAbstractConnection* newconn,
 	jammo_state newstate,
 	gint32 newjammoid)
 {
-	gems_connection* new_item = (gems_connection*)g_malloc(sizeof(gems_connection));
+	gems_connection* new_item = g_new(gems_connection,sizeof(gems_connection));
 	
 	new_item->connection = newconn;
 	new_item->game_connection = NULL;
@@ -312,8 +312,7 @@ gchar* gems_connection_get_data(gems_connection* element, guint from, guint leng
 {
 	if(element == NULL) return NULL;
 	
-	gchar* buffer = (gchar*)g_malloc(sizeof(gchar*)*length);
-	memset(buffer,'\0',length);
+	gchar* buffer = g_new0(gchar,sizeof(gchar)*length);
 
 	memcpy(buffer, &element->nwbuffer[from],length);
 		
@@ -370,7 +369,7 @@ gems_peer_profile* gems_new_peer_profile(gchar* username, guint32 id, guint16 ag
 {
 	if(username == NULL) return NULL;
 	 
-	gems_peer_profile* profile = (gems_peer_profile*)g_malloc(sizeof(gems_peer_profile));
+	gems_peer_profile* profile = g_new(gems_peer_profile,sizeof(gems_peer_profile));
 	
 	profile->id = id;
 	profile->username = g_strdup(username);
@@ -644,7 +643,7 @@ GList* gems_connection_error_add(GList* list, guint device_checksum, guint error
 	// Not found -> create new and add
 	if((item = gems_connection_error_get(list,device_checksum)) == NULL)
 	{
-		item = (gems_connection_error*)g_malloc(sizeof(gems_connection_error));
+		item = g_new(gems_connection_error,sizeof(gems_connection_error));
 		item->checksum = device_checksum;
 		
 		if(errortype == ERROR_CONNECTION) item->connection_errors = 1;
@@ -717,7 +716,7 @@ guint gems_connection_error_get_connection_error_count(GList* list, guint device
 gboolean gems_connection_error_attempt_connection(GList* list, guint device_checksum)
 {
 	gems_connection_error* item = gems_connection_error_get(list,device_checksum);
-	gdouble time = 0.0;
+	gdouble err_time = 0.0;
 	
 	if(item == NULL)
 	{
@@ -727,9 +726,9 @@ gboolean gems_connection_error_attempt_connection(GList* list, guint device_chec
 	else
 	{
 		// reached errorlimit -> longer interval
-		if(item->connection_errors > CONNECTION_ERRORLIMIT)	time = CONNECTION_INTERVAL * 10 + item->connection_errors;
+		if(item->connection_errors > CONNECTION_ERRORLIMIT)	err_time = CONNECTION_INTERVAL * 10 + item->connection_errors;
 		// Each error gives 1s more delay
-		else time = item->connection_errors + CONNECTION_INTERVAL;
+		else err_time = item->connection_errors + CONNECTION_INTERVAL;
 		
 		//logmsg = g_strdup_printf("gems_connection_error_attempt_connection: checking time for %d, time = %f, errors = %d", item->checksum, time, item->connection_errors);
 		
@@ -737,7 +736,7 @@ gboolean gems_connection_error_attempt_connection(GList* list, guint device_chec
 		if(item->already_connected) return FALSE;
 		
 		// less than 'time' elapsed?
-		if(g_timer_elapsed(item->connection_timer,NULL) < time)
+		if(g_timer_elapsed(item->connection_timer,NULL) < err_time)
 		{
 			//logmsg = g_strdup_printf("gems_connection_error_attempt_connection: %f passed ", g_timer_elapsed(item->connection_timer,NULL));
 			return FALSE;
