@@ -26,10 +26,10 @@ License:LGPL 2.1
 //#define SLIDER_FOLDER DATA_DIR "/virtual-instruments/slider/"
 
 static const GstElementDetails gst_jammo_looper_details =
-GST_ELEMENT_DETAILS ("JamMo Looper",
-    "Source/Audio",
-    "JamMo Looper",
-    "Mikko Gynther <mikko.gynther@lut.fi>");
+GST_ELEMENT_DETAILS ((gchar*)"JamMo Looper",
+    (gchar*)"Source/Audio",
+    (gchar*)"JamMo Looper",
+    (gchar*)"Mikko Gynther <mikko.gynther@lut.fi>");
 
 #define DEFAULT_SAMPLES_PER_BUFFER   256
 #define DEFAULT_VOLUME               0.6
