@@ -35,10 +35,10 @@ License:LGPL 2.1
 #define M_PI_M2 ( M_PI + M_PI )
 
 static const GstElementDetails gst_jammo_sampler_details =
-GST_ELEMENT_DETAILS ("JamMo Virtual Instrument",
-    "Source/Audio",
-    "Creates virtual instrument",
-    "Aapo Rantalainen <aapo.rantalainen@gmail.com>, Mikko Gynther <mikko.gynther@lut.fi>");
+GST_ELEMENT_DETAILS ( (gchar*)"JamMo Virtual Instrument",
+     (gchar*)"Source/Audio",
+     (gchar*)"Creates virtual instrument",
+     (gchar*)"Aapo Rantalainen <aapo.rantalainen@gmail.com>, Mikko Gynther <mikko.gynther@lut.fi>");
 
 #define DEFAULT_SAMPLES_PER_BUFFER   512
 #define DEFAULT_VOLUME               0.6
@@ -341,7 +341,7 @@ static void gst_jammo_sampler_init (GstJammoSampler * src, GstJammoSamplerClass
   src->format = GST_JAMMO_SAMPLER_FORMAT_NONE;
 
   src->volume = DEFAULT_VOLUME;
-  src->base_folder= "";
+  src->base_folder = g_strdup_printf("default");
 
   //All notes start silently
   for (i=0;i<JAMMOMIDI_NUMBER_OF_NOTES;i++)
@@ -540,13 +540,13 @@ static gfloat looping_sampler(GstJammoSampler * src, gint j) {
 					value= sampletable[(gint)*sampleindex] / (G_MAXINT16*1.0) * scale;
 				}
 				else {
-					value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
+					value=( jammo_gst_do_interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 				}
 			}
 			/* move sampleindex according to needed pitch */
 			/* samplerate variable has the output samplerate of jammosampler */
 			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
+			src->wav_based_instrument[j]->sampleindex += jammo_gst_do_pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* if note has been released after previous round */
 			if (src->wav_based_instrument[j]->released) {
@@ -592,7 +592,7 @@ static gfloat looping_sampler(GstJammoSampler * src, gint j) {
 
 			/* xfade when looping */
 			if (*xfadecounter >= 0.0 && *sampleindex < src->wav_based_instrument[j]->loop_end) {
-					value=xfader(sampletable, xfadecounter, xfadeindex, *xfade, value, scale, src->wav_based_instrument[j]->needed_pitch, src->samplerate);
+					value=jammo_gst_do_xfader(sampletable, xfadecounter, xfadeindex, *xfade, value, scale, src->wav_based_instrument[j]->needed_pitch, src->samplerate);
 					/* End x fade if enough rounds */\
 					if (*xfadecounter > *xfade) {
 						*xfadecounter=-1.0;
@@ -639,13 +639,13 @@ static gfloat nonlooping_sampler(GstJammoSampler * src, gint j) {
 					value= sampletable[(gint)*sampleindex] / (G_MAXINT16*1.0) * scale;
 				}
 				else {
-					value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
+					value=( jammo_gst_do_interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 				}
 			}
 			/* move sampleindex according to needed pitch */
 			/* samplerate variable has the output samplerate of jammosampler */
 			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
+			src->wav_based_instrument[j]->sampleindex += jammo_gst_do_pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* if note has been released after previous round */
 			if (src->wav_based_instrument[j]->released) {
@@ -720,13 +720,13 @@ static gfloat oneshot_sampler(GstJammoSampler * src, gint j) {
 					value= sampletable[(gint)*sampleindex] / (G_MAXINT16*1.0) * scale;
 				}
 				else {
-					value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
+					value=( jammo_gst_do_interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 				}
 			}
 			/* move sampleindex according to needed pitch */
 			/* samplerate variable has the output samplerate of jammosampler */
 			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
+			src->wav_based_instrument[j]->sampleindex += jammo_gst_do_pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* fade in to prevent clicks and pops*/
 			if (*sampleindex<50) {
@@ -1328,37 +1328,6 @@ static void get_token(gchar **value){
 }
 ////////////////////////////////////////////
 
-
-/*
- Returns time difference between current time
- and creation_time  
-*/
-struct timeval calc_timestamp (struct timeval creation_time) {
-  struct timeval result;
-
-  struct timeval now;
-  gettimeofday(&now, NULL);
-
-  if (now.tv_usec < creation_time.tv_usec) {
-    int nsec = (creation_time.tv_usec - now.tv_usec) / 1000000 + 1;
-    creation_time.tv_usec -= 1000000 * nsec;
-    creation_time.tv_sec += nsec;
-  }
-  if (now.tv_usec - creation_time.tv_usec > 1000000) {
-    int nsec = (now.tv_usec - creation_time.tv_usec) / 1000000;
-    creation_time.tv_usec += 1000000 * nsec;
-    creation_time.tv_sec -= nsec;
-  }
-
-  /* Compute the time.
-     tv_usec is certainly positive. */
-  result.tv_sec = now.tv_sec - creation_time.tv_sec;
-  result.tv_usec = now.tv_usec - creation_time.tv_usec;
-
-  return result;
-}
-
-
 static void
 gst_jammo_sampler_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
