@@ -52,10 +52,10 @@ License:LGPL 2.1
 #define SLIDER_FOLDER AUDIO_DIR "/virtual-instruments/slider/"
 
 static const GstElementDetails gst_jammo_slider_details =
-GST_ELEMENT_DETAILS ("JamMo Slider",
-    "Source/Audio",
-    "JamMo Slider",
-    "Aapo Rantalainen <aapo.rantalainen@gmail.com>, Mikko Gynther <mikko.gynther@lut.fi>");
+GST_ELEMENT_DETAILS ((gchar*)"JamMo Slider",
+    (gchar*)"Source/Audio",
+    (gchar*)"JamMo Slider",
+    (gchar*)"Aapo Rantalainen <aapo.rantalainen@gmail.com>, Mikko Gynther <mikko.gynther@lut.fi>");
 
 #define DEFAULT_SAMPLES_PER_BUFFER   256
 #define DEFAULT_INSTRUMENT           0
@@ -158,7 +158,7 @@ static void gst_jammo_slider_base_init (gpointer g_class)
   gst_element_class_set_details (element_class, &gst_jammo_slider_details);
 }
 
-void init_sine_table(gfloat * sine_table, gint size) {
+static void init_sine_table(gfloat * sine_table, gint size) {
 	gint i;
 	for (i=0;i<size;i++) {
 		sine_table[i]=sinf(i/(gfloat)size * M_PI_M2);
@@ -166,7 +166,7 @@ void init_sine_table(gfloat * sine_table, gint size) {
 }
 
 /* Very simple organ type sound additive synthesis algorithm.*/
-void init_organ_table(gfloat * organ_table, gint size) {
+static void init_organ_table(gfloat * organ_table, gint size) {
 	gint i;
 	for (i=0;i<size;i++) {
 		organ_table[i]=0.6*(1 * sinf(i/(gfloat)size * M_PI_M2)  + 1.0/6 *sinf((i/(gfloat)size * M_PI_M2)*2) + 1.0/3*sinf((i/(gfloat)size * M_PI_M2)*3) + 1.0/4*sinf((i/(gfloat)size * M_PI_M2)*4)+1.0/3*sinf((i/(gfloat)size * M_PI_M2)*5)+1.0/6*sinf((i/(gfloat)size * M_PI_M2)*6)+1.0/6*sinf((i/(gfloat)size * M_PI_M2)*7)+1.0/4*sinf((i/(gfloat)size * M_PI_M2)*8));
@@ -174,14 +174,14 @@ void init_organ_table(gfloat * organ_table, gint size) {
 }
 
 /* fm synthesis algorithm */
-void init_fm_table(gfloat * fm_table, gint size) {
+static void init_fm_table(gfloat * fm_table, gint size) {
 	gint i;
 	for (i=0;i<size;i++) {
 		fm_table[i]=( sinf((i/(gfloat)size * M_PI_M2)+0.6*sinf((i/(gfloat)size * M_PI_M2)*8.0)) );
 	}
 }
 
-gfloat sine_value(GstJammoSlider * src, gfloat phase) {
+static gfloat sine_value(GstJammoSlider * src, gfloat phase) {
 	while (phase>M_PI_M2) phase-=M_PI_M2;
 	return src->sine_table[(gint)(phase/M_PI_M2*src->table_size)];
 }
@@ -191,13 +191,13 @@ Some day we will have three different instrument using slider.
 Organ and fm_modulation are only for testing.
 */
 
-gfloat organ(GstJammoSlider * src, gdouble phase){
+static gfloat organ(GstJammoSlider * src, gdouble phase){
 	while (phase>M_PI_M2) phase-=M_PI_M2;
 	return src->organ_table[(gint)(phase/M_PI_M2*src->table_size)];
 }
 
 
-gfloat fm_modulation(GstJammoSlider * src, gdouble phase){
+static gfloat fm_modulation(GstJammoSlider * src, gdouble phase){
 	while (phase>M_PI_M2) phase-=M_PI_M2;
 	return src->fm_table[(gint)(phase/M_PI_M2*src->table_size)];
 }
@@ -207,14 +207,14 @@ gfloat fm_modulation(GstJammoSlider * src, gdouble phase){
 
 #define MAXDEL  (2048)       /* MUST be a power of 2. */
 #define BITMASK (MAXDEL-1)  /* Circular buffer. */
-short    y[MAXDEL];
-long     ap=0;
-short    n=0;
+static short    y[MAXDEL];
+static long     ap=0;
+static short    n=0;
 
-short karplus_strong (short x, gfloat length) {
+static short karplus_strong (short x, gfloat length) {
   long            a, b;       /* No need to remember a and b. */
 
-  a = (long)x + interpolation(length-(int)length, y[((gint)(n - length)) & BITMASK],y[((gint)(n - (length+1))) & BITMASK]); /* interpolation */
+  a = (long)x + jammo_gst_do_interpolation(length-(int)length, y[((gint)(n - length)) & BITMASK],y[((gint)(n - (length+1))) & BITMASK]); /* interpolation */
 
   //b = ((a + ap) * 127) >> 8;            /* Coeff = +0.49609375. */
     b = ((a + ap) * 127) / (255);
@@ -224,7 +224,7 @@ short karplus_strong (short x, gfloat length) {
 }
 
 
-gfloat karplus(GstJammoSlider * src){
+static gfloat karplus(GstJammoSlider * src){
   gfloat freq = src->freq_slow;
   short inp;
   if (src->adsr_counter < src->samplerate/freq)  /* white noise BURST. */
@@ -232,7 +232,7 @@ gfloat karplus(GstJammoSlider * src){
   else                                           /* No more input (silence). */
       inp = 0;
 
-return (gfloat) karplus_strong(inp, src->samplerate/freq)/32767;
+return karplus_strong(inp, src->samplerate/freq)/32767.0; //short divided by float
 }
 
 static JammoSliderInstrumentFunc instruments[] = {
@@ -629,7 +629,7 @@ static gfloat freq_rounding_new_note(gfloat freq){
 }
 
 // a function for initializing parameters when starting to play a new note
-void process_slider_event_on(GstJammoSlider * src, float freq) {
+static void process_slider_event_on(GstJammoSlider * src, float freq) {
 	src->state=TRUE;
 	src->freq=freq;
 	src->released=FALSE;
@@ -646,14 +646,14 @@ void process_slider_event_on(GstJammoSlider * src, float freq) {
 	src->freq_slow=freq_rounding_new_note(freq);
 }
 
-void process_slider_event_off(GstJammoSlider * src, float freq) {
+static void process_slider_event_off(GstJammoSlider * src, float freq) {
 	src->released=TRUE;
 	src->freq=freq;
 	src->rounding_counter=0;
 	src->rounded=FALSE;
 }
 
-void process_slider_event_motion(GstJammoSlider * src, float freq) {
+static void process_slider_event_motion(GstJammoSlider * src, float freq) {
 	src->freq=freq;
 	src->rounding_counter=0;
 	src->rounded=FALSE;
@@ -687,7 +687,7 @@ static void do_playback_process(GstJammoSlider * src){
 
 	while (src->time * src->tempo_scale > timestamp){
 		//printf("DEBUG: gstjammoslider: delayed: %llu ms, freq: %f, type: %d\n",(unsigned long long) ((src->time * src->tempo_scale - timestamp)/src->tempo_scale)/1000/1000, event->freq, event->type);
-		gfloat freq=event->freq * pitch(src->pitch_shift);
+		gfloat freq=event->freq * jammo_gst_do_pitch(src->pitch_shift);
 
 		if (freq >= MINFREQ && freq <= MAXFREQ) {
 			if (event->type==JAMMO_SLIDER_EVENT_ON ) {
@@ -856,7 +856,7 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 	if (src->freq!=src->last_reported_frequency) {\
 		src->last_reported_frequency=src->freq; \
 		GstStructure *s;\
-		s = gst_structure_new ("slider", "frequency", G_TYPE_FLOAT, src->freq * pitch(-src->pitch_shift), NULL);\
+		s = gst_structure_new ("slider", "frequency", G_TYPE_FLOAT, src->freq * jammo_gst_do_pitch(-src->pitch_shift), NULL);\
 \
 		GstMessage *m = gst_message_new_element (GST_OBJECT (src), s);\
 		gst_element_post_message (GST_ELEMENT (src), m);\
@@ -1194,6 +1194,8 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
 {
   GstJammoSlider *src = GST_JAMMO_SLIDER (object);
+  GList* list; //used when looping over eventlist
+  JammoSliderEvent* event_iterator;  //used when looping over eventlist
 
   switch (prop_id) {
     case PROP_SAMPLES_PER_BUFFER:
@@ -1234,22 +1236,19 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 			;
 			// note that remove removes only one event
 			// to remove a note one has to remove on, off, and possible motion events
-			JammoSliderEvent* event = (JammoSliderEvent*)(g_value_get_pointer(value));
-
-			GList* list;
-			JammoSliderEvent* n;
+			JammoSliderEvent* removed_event = (JammoSliderEvent*)(g_value_get_pointer(value));
 
 			//printf("Removing this: %llu ms: note:%d \n",(unsigned long long)time,note_);
 			for (list = src->eventlist; list; list = list->next) {
 				//printf(".\n");
-				n = (list->data);
+				event_iterator = (list->data);
 				//printf("Scanning stack: %llu ms: freq:%f ,type: %d \n", (unsigned long long)n->timestamp,n->freq, n->type);
 
 				// find and remove
-				if (n->type==event->type && n->freq==event->freq && n->timestamp==event->timestamp) {
+				if (event_iterator->type==removed_event->type && event_iterator->freq==removed_event->freq && event_iterator->timestamp==removed_event->timestamp) {
 					printf("event removed\n");
-					src->eventlist = g_list_remove(src->eventlist,n);
-					g_free(n);
+					src->eventlist = g_list_remove(src->eventlist,event_iterator);
+					g_free(event_iterator);
 				}
 
 			}
@@ -1259,9 +1258,8 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 
     case PROP_ADD_EVENT:
 			;
-			//JammoSliderEvent* event;
-			event = (JammoSliderEvent*)(g_value_get_pointer(value));
-			guint64 timestamp = event->timestamp;
+			JammoSliderEvent* added_event = (JammoSliderEvent*)(g_value_get_pointer(value));
+			guint64 timestamp = added_event->timestamp;
 			gboolean store=TRUE;
 
 			//realtime. There are no timestamp in event, use current time
@@ -1269,20 +1267,19 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 				//printf("realtime\n");
 				timestamp = src->time * src->tempo_scale;
 
-				if (event->type==JAMMO_SLIDER_EVENT_ON) {
-					process_slider_event_on(src, event->freq * pitch(src->pitch_shift));
+				if (added_event->type==JAMMO_SLIDER_EVENT_ON) {
+					process_slider_event_on(src, added_event->freq * jammo_gst_do_pitch(src->pitch_shift));
 				}
-				else if (event->type==JAMMO_SLIDER_EVENT_OFF) {
-					process_slider_event_off(src, event->freq * pitch(src->pitch_shift));
+				else if (added_event->type==JAMMO_SLIDER_EVENT_OFF) {
+					process_slider_event_off(src, added_event->freq * jammo_gst_do_pitch(src->pitch_shift));
 				}
-				else if (event->type==JAMMO_SLIDER_EVENT_MOTION) {
+				else if (added_event->type==JAMMO_SLIDER_EVENT_MOTION) {
 					if (src->state==TRUE) {
-						process_slider_event_motion(src, event->freq * pitch(src->pitch_shift));
+						process_slider_event_motion(src, added_event->freq * jammo_gst_do_pitch(src->pitch_shift));
 						// check if event can be discarded
 						if (src->previous_event.type==JAMMO_SLIDER_EVENT_MOTION &&
 							timestamp - src->time_of_last_stored_event < DISCARDTIME) {
 							// find previous event from the list
-							GList * list;
 							JammoSliderEvent * temp_event;
 							for (list=src->eventlist;list;list=list->next) {
 								temp_event=list->data;
@@ -1305,14 +1302,14 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 
 			else { //adding non-realtime (nothing special)
 				//printf("non-realtime\n");
-				timestamp=event->timestamp;
+				timestamp=added_event->timestamp;
 			}
 
 			if (store) {
-				jammo_slider_event_store_event_to_glist(&(src->eventlist) ,event->freq, event->type, timestamp);
+				jammo_slider_event_store_event_to_glist(&(src->eventlist) ,added_event->freq, added_event->type, timestamp);
 				//printf("DEBUG: gstjammoslider: added event %llu ms: freq:'%f', type=%d\n",(unsigned long long)(timestamp/1000/1000),event->freq,event->type);
-				src->previous_event.type=event->type;
-				src->previous_event.freq=event->freq;
+				src->previous_event.type=added_event->type;
+				src->previous_event.freq=added_event->freq;
 				src->previous_event.timestamp=timestamp;
 				src->time_of_last_stored_event=timestamp;
 			}
@@ -1335,11 +1332,11 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
 			jammo_slider_event_free_glist(&(src->eventlist));
 			src->eventlist=NULL;
       for (list = g_value_get_pointer (value); list; list = list->next) {
-        n = (list->data);
+        event_iterator = (list->data);
         //printf("CASE PROP_EVENTLIST:gstjammosampler:Add: %llu ns: note:%d ,type: %s \n", (unsigned long long)n->timestamp,n->note, n->type==0? "start":"stop");
 				// we want to allocate memory for the event so that nothing else will delete events
 				// from samplers list
-				jammo_slider_event_store_event_to_glist(&(src->eventlist), n->freq, n->type, n->timestamp);
+				jammo_slider_event_store_event_to_glist(&(src->eventlist), event_iterator->freq, event_iterator->type, event_iterator->timestamp);
         }
 			break;
     case PROP_TEMPO_SCALE:
