@@ -105,7 +105,7 @@ This should be only function loading midi events from file.
 Will return NULL (=empty list), if filename is NULL, or file not found
  (or no access to read it...)
 */
-GList * jammomidi_file_to_glist(char * filename) {
+GList* jammomidi_file_to_glist(const char* filename){
 	FILE * fp;
 	GList * list;
 
